==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailCustomizationAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailCustomizationAllOfLinks
 */
@JsonPropertyOrder({ EmailCustomizationAllOfLinks.JSON_PROPERTY_SELF,
        EmailCustomizationAllOfLinks.JSON_PROPERTY_TEMPLATE, EmailCustomizationAllOfLinks.JSON_PROPERTY_PREVIEW,
        EmailCustomizationAllOfLinks.JSON_PROPERTY_TEST })
@JsonTypeName("EmailCustomization_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class EmailCustomizationAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObject self;

    public static final String JSON_PROPERTY_TEMPLATE = "template";
    private HrefObject template;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private HrefObject preview;

    public static final String JSON_PROPERTY_TEST = "test";
    private HrefObject test;

    public EmailCustomizationAllOfLinks() {
    }

    public EmailCustomizationAllOfLinks self(HrefObject self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObject self) {
        this.self = self;
    }

    public EmailCustomizationAllOfLinks template(HrefObject template) {

        this.template = template;
        return this;
    }

    /**
     * Get template
     *
     * @return template
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEMPLATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTemplate() {
        return template;
    }

    @JsonProperty(JSON_PROPERTY_TEMPLATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTemplate(HrefObject template) {
        this.template = template;
    }

    public EmailCustomizationAllOfLinks preview(HrefObject preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(HrefObject preview) {
        this.preview = preview;
    }

    public EmailCustomizationAllOfLinks test(HrefObject test) {

        this.test = test;
        return this;
    }

    /**
     * Get test
     *
     * @return test
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTest() {
        return test;
    }

    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTest(HrefObject test) {
        this.test = test;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailCustomizationAllOfLinks emailCustomizationAllOfLinks = (EmailCustomizationAllOfLinks) o;
        return Objects.equals(this.self, emailCustomizationAllOfLinks.self)
                && Objects.equals(this.template, emailCustomizationAllOfLinks.template)
                && Objects.equals(this.preview, emailCustomizationAllOfLinks.preview)
                && Objects.equals(this.test, emailCustomizationAllOfLinks.test);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, template, preview, test);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailCustomizationAllOfLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    template: ").append(toIndentedString(template)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("    test: ").append(toIndentedString(test)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/EmailCustomizationAllOfLinks.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.HrefObject;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * EmailCustomizationAllOfLinks
 */
@JsonPropertyOrder({ EmailCustomizationAllOfLinks.JSON_PROPERTY_SELF,
        EmailCustomizationAllOfLinks.JSON_PROPERTY_TEMPLATE, EmailCustomizationAllOfLinks.JSON_PROPERTY_PREVIEW,
        EmailCustomizationAllOfLinks.JSON_PROPERTY_TEST })
@JsonTypeName("EmailCustomization_allOf__links")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class EmailCustomizationAllOfLinks implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_SELF = "self";
    private HrefObject self;

    public static final String JSON_PROPERTY_TEMPLATE = "template";
    private HrefObject template;

    public static final String JSON_PROPERTY_PREVIEW = "preview";
    private HrefObject preview;

    public static final String JSON_PROPERTY_TEST = "test";
    private HrefObject test;

    public EmailCustomizationAllOfLinks() {
    }

    public EmailCustomizationAllOfLinks self(HrefObject self) {

        this.self = self;
        return this;
    }

    /**
     * Get self
     *
     * @return self
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getSelf() {
        return self;
    }

    @JsonProperty(JSON_PROPERTY_SELF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setSelf(HrefObject self) {
        this.self = self;
    }

    public EmailCustomizationAllOfLinks template(HrefObject template) {

        this.template = template;
        return this;
    }

    /**
     * Get template
     *
     * @return template
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEMPLATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTemplate() {
        return template;
    }

    @JsonProperty(JSON_PROPERTY_TEMPLATE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTemplate(HrefObject template) {
        this.template = template;
    }

    public EmailCustomizationAllOfLinks preview(HrefObject preview) {

        this.preview = preview;
        return this;
    }

    /**
     * Get preview
     *
     * @return preview
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getPreview() {
        return preview;
    }

    @JsonProperty(JSON_PROPERTY_PREVIEW)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPreview(HrefObject preview) {
        this.preview = preview;
    }

    public EmailCustomizationAllOfLinks test(HrefObject test) {

        this.test = test;
        return this;
    }

    /**
     * Get test
     *
     * @return test
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public HrefObject getTest() {
        return test;
    }

    @JsonProperty(JSON_PROPERTY_TEST)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTest(HrefObject test) {
        this.test = test;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        EmailCustomizationAllOfLinks emailCustomizationAllOfLinks = (EmailCustomizationAllOfLinks) o;
        return Objects.equals(this.self, emailCustomizationAllOfLinks.self)
                && Objects.equals(this.template, emailCustomizationAllOfLinks.template)
                && Objects.equals(this.preview, emailCustomizationAllOfLinks.preview)
                && Objects.equals(this.test, emailCustomizationAllOfLinks.test);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(self, template, preview, test);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class EmailCustomizationAllOfLinks {\n");
        sb.append("    self: ").append(toIndentedString(self)).append("\n");
        sb.append("    template: ").append(toIndentedString(template)).append("\n");
        sb.append("    preview: ").append(toIndentedString(preview)).append("\n");
        sb.append("    test: ").append(toIndentedString(test)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
